/*
 * minor_mode.h
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _MINOR_MODE_H_
#define _MINOR_MODE_H_


#include "mode_base.h"
#include "drawer.h"


class MinorMode : public ModeBase, public Drawer
{
public:

	/**
	 * Constructor.
	 *
	 * @param num_flavours the number of flavours in this minor display mode
	 */
	MinorMode( int num_flavours );

	/**
	 * Called to inform the mode that there has been a (short) button press.
	 */
	virtual void press();

	/**
	 * Called when this major mode is becoming active
	 */
	virtual void activate();

	/**
	 * Retrieve a drawer.
	 *
	 * @return drawer
	 */
	Drawer &get_drawer();

protected:

	/**
	 * Get the current flavour.
	 *
	 * @return flavour
	 */
	int get_flavour();

	/** current flavour */
	int _flavour;

	/** number of flavours */
	int _num_flavours;
	 
};


#endif //_MINOR_MODE_H_
