/*
 * switcher_major_mode.cc
 *
 * Copyright (C) 2011 Tim Marston <tim@ed.am> and Dan Marston.
 *
 * This file is part of propeller-clock (hereafter referred to as "this
 * program"). See http://ed.am/dev/software/arduino/propeller-clock for more
 * information.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "switcher_major_mode.h"
#include "test_mode.h"
#include "analogue_clock_mode.h"
#include "digital_clock_mode.h"
#include "Arduino.h"


SwitcherMajorMode::SwitcherMajorMode()
{
	for( int a = 0; a < MAX_MINOR_MODES; a++ )
		_modes[ a ] = NULL;

	static TestMode test_mode;
	static AnalogueClockMode analogue_clock_mode;
	static DigitalClockMode digital_clock_mode;

	int mode = 0;
	_modes[ mode++ ] = &digital_clock_mode;
	_modes[ mode++ ] = &test_mode;
	_modes[ mode++ ] = &analogue_clock_mode;
}


void SwitcherMajorMode::press()
{
	_modes[ _mode ]->press();
}


void SwitcherMajorMode::long_press()
{
	do {
		if( ++_mode >= MAX_MINOR_MODES )
			_mode = 0;
	} while( _modes[ _mode ] == NULL );
	_modes[ _mode ]->activate();
}


void SwitcherMajorMode::activate()
{
	_mode = 0;
	_modes[ _mode ]->activate();
}


Drawer &SwitcherMajorMode::get_drawer()
{
	return *_modes[ _mode ];
}
